# remirepo spec file for php-pecl-ev
#
# SPDX-FileCopyrightText:  Copyright 2013-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#
#
# NOTE: bundled libev
#
%{?scl:%scl_package php-pecl-ev}

%bcond_without           tests

%global pecl_name        ev
%global pie_vend         osmanov
%global pie_proj         pecl-ev
%global with_zts         0%{!?_without_zts:%{?__ztsphp:1}}
# After 20-sockets
%global ini_name         40-%{pecl_name}.ini
%global upstream_version 1.2.1
#global upstream_prever  RC1
#global upstream_postver r1
%global sources          %{pecl_name}-%{upstream_version}%{?upstream_prever}%{?upstream_postver}
%global _configure       ../%{sources}/configure

Summary:        Provides interface to libev library
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        %{upstream_version}%{?upstream_prever:~%{upstream_prever}}%{?upstream_postver:+%{upstream_postver}}
Release:        1%{?dist}%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}
License:        PHP-3.01
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{sources}.tgz

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 8.0
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  %{?scl_prefix}php-sockets
# For tests
BuildRequires:  %{?scl_prefix}php-posix

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
Requires:       %{?scl_prefix}php-sockets%{?_isa}

Provides:       %{?scl_prefix}php-%{pecl_name}                 = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})           = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa}   = %{version}
Provides:       %{?scl_prefix}php-pie(%{pie_vend}/%{pie_proj}) = %{version}
Provides:       %{?scl_prefix}php-%{pie_vend}-%{pie_proj}      = %{version}


%description
The ev extension provides interface to libev library - high performance
full-featured event loop written in C.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

# Don't register test files on install
sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

cd %{sources}
# Sanity check, really often broken
extver=$(sed -n '/define PHP_EV_VERSION/{s/.* "//;s/".*$//;p}' php_ev.h)
if test "x${extver}" != "x%{upstream_version}%{?upstream_prever}%{?upstream_postver}"; then
   : Error: Upstream extension version is ${extver}, expecting %{upstream_version}%{?upstream_prever}%{?upstream_postver}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

# Create configuration file
cat > %{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}
sed -e 's/INSTALL_ROOT/DESTDIR/' -i build/Makefile.global

cd ../NTS
%configure \
    --with-libdir=%{_lib} \
    --with-php-config=%{__phpconfig}

%make_build

%if %{with_zts}
cd ../ZTS
%configure \
    --with-libdir=%{_lib} \
    --with-php-config=%{__ztsphpconfig}

%make_build
%endif


%install
%{?dtsenable}

%make_install -C NTS

# install config file - z-eio.ini to ensure load order (after sockets)
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
%make_install -C ZTS

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Test & Documentation
cd %{sources}
for i in $(grep 'role="doc"' ../package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
cd %{sources}

DEPMOD="-n"
[ -f %{php_extdir}/sockets.so ] && DEPMOD="$DEPMOD -d extension=sockets.so"
[ -f %{php_extdir}/posix.so ]   && DEPMOD="$DEPMOD -d extension=posix.so"

: Minimal load test for NTS extension
%{__php} \
    $DEPMOD \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite for NTS extension
TEST_PHP_ARGS="$DEPMOD -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
%{__php} -n run-tests.php -q --show-diff %{?_smp_mflags}
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} \
    $DEPMOD \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'
%endif


%files
%license %{sources}/LICENSE
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Thu Jul 17 2025 Remi Collet <remi@remirepo.net> - 1.2.1-1
- update to 1.2.1
- drop patch merged upstream

* Thu Jul 17 2025 Remi Collet <remi@remirepo.net> - 1.2.0-3
- add patch for PHP 8.5.0alpha2 (sent to author)

* Tue Sep 24 2024 Remi Collet <remi@remirepo.net> - 1.2.0-2
- rebuild for 8.4.0RC1

* Tue Sep  3 2024 Remi Collet <remi@remirepo.net> - 1.2.0-1
- update to 1.2.0

* Fri Sep  1 2023 Remi Collet <remi@remirepo.net> - 1.1.6~RC1-2
- build out of sources tree

* Sat Nov 13 2021 Remi Collet <remi@remirepo.net> - 1.1.6~RC1-1
- update to 1.1.6RC1

* Sat Sep 18 2021 Remi Collet <remi@remirepo.net> - 1.1.5-1
- update to 1.1.5

* Wed Sep 01 2021 Remi Collet <remi@remirepo.net> - 1.1.4-2
- rebuild for 8.1.0RC1

* Mon Jul 26 2021 Remi Collet <remi@remirepo.net> - 1.1.4-1
- update to 1.1.4
- drop patches merged upstream

* Mon Jul 26 2021 Remi Collet <remi@remirepo.net> - 1.1.3-1
- update to 1.1.3
- add patch for PHP 5 and ZTS (send upstream by email)
- add patch for PHP 8.1.0beta1 (send upstream by email)

* Tue Feb 16 2021 Remi Collet <remi@remirepo.net> - 1.1.2-1
- update to 1.1.2

* Tue Feb 16 2021 Remi Collet <remi@remirepo.net> - 1.1.1+r1-1
- update to 1.1.1r1 (stable)

* Thu Feb  4 2021 Remi Collet <remi@remirepo.net> - 1.1.1-1
- update to 1.1.1

* Tue Feb  2 2021 Remi Collet <remi@remirepo.net> - 1.1.0-1
- update to 1.1.0

* Thu Nov 19 2020 Remi Collet <remi@remirepo.net> - 1.0.9-1
- update to 1.0.9

* Tue Dec 10 2019 Remi Collet <remi@remirepo.net> - 1.0.8-1
- update to 1.0.8

* Sun Dec  8 2019 Remi Collet <remi@remirepo.net> - 1.0.7-1
- update to 1.0.7

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 1.0.6-5
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 1.0.6-4
- rebuild for 7.4.0beta1

* Wed May 29 2019 Remi Collet <remi@remirepo.net> - 1.0.6-3
- rebuild

* Mon May 27 2019 Remi Collet <remi@remirepo.net> - 1.0.6-1
- update to 1.0.6

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 1.0.4-2
- rebuild for PHP 7.2.0beta1 new API

* Fri Dec  2 2016 Remi Collet <remi@fedoraproject.org> - 1.0.4-1
- Update to 1.0.4

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 1.0.3-3
- rebuild with PHP 7.1.0 GA

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 1.0.3-2
- rebuild for PHP 7.1 new API version

* Fri Jul 29 2016 Remi Collet <remi@fedoraproject.org> - 1.0.3-1
- Update to 1.0.3

* Fri Jul 29 2016 Remi Collet <remi@fedoraproject.org> - 1.0.2-1
- Update to 1.0.2 (stable)

* Fri Jul 29 2016 Remi Collet <remi@fedoraproject.org> - 1.0.1-1
- Update to 1.0.1 (stable)
- ignore 1 failed test with PHP 5.4, see
  https://bitbucket.org/osmanov/pecl-ev/issues/28/101-failed-test-with-php-54

* Tue May 17 2016 Remi Collet <remi@fedoraproject.org> - 1.0.0-1
- update to 1.0.0 (stable)

* Sat Mar  5 2016 Remi Collet <remi@fedoraproject.org> - 1.0.0-0.7.RC9
- adapt for F24

* Thu Feb 25 2016 Remi Collet <remi@fedoraproject.org> - 1.0.0-0.6.RC9
- Update to 1.0.0RC9 (php 5 and 7, beta)

* Mon Feb 22 2016 Remi Collet <remi@fedoraproject.org> - 1.0.0-0.5.RC8
- Update to 1.0.0RC8

* Thu Feb 11 2016 Remi Collet <remi@fedoraproject.org> - 1.0.0-0.4.RC4
- Update to 1.0.0RC4

* Wed Dec 16 2015 Remi Collet <remi@fedoraproject.org> - 1.0.0-0.3.RC3
- Update to 1.0.0RC3

* Wed Nov 25 2015 Remi Collet <remi@fedoraproject.org> - 1.0.0-0.2.RC2
- Update to 1.0.0RC2

* Fri Nov 20 2015 Remi Collet <remi@fedoraproject.org> - 1.0.0-0.1.RC1
- Update to 1.0.0RC1
- open https://bitbucket.org/osmanov/pecl-ev/issues/16 - ZTS segfault

* Mon May 04 2015 Remi Collet <remi@fedoraproject.org> - 0.2.15-1
- Update to 0.2.15 (stable, no change)
- drop runtime dependency on pear, new scriptlets

* Wed Dec 24 2014 Remi Collet <remi@fedoraproject.org> - 0.2.13-1.1
- Fedora 21 SCL mass rebuild

* Tue Dec 09 2014 Remi Collet <remi@fedoraproject.org> - 0.2.13-1
- Update to 0.2.13 (stable, no change)

* Tue Sep 09 2014 Remi Collet <remi@fedoraproject.org> - 0.2.12-1
- Update to 0.2.12 (no change, only our patch merged)
- enable posix during build as some tests need it

* Mon Sep  8 2014 Remi Collet <rcollet@redhat.com> - 0.2.11-2
- open https://bitbucket.org/osmanov/pecl-ev/pull-request/3
- enable ZTS build

* Mon Sep  8 2014 Remi Collet <rcollet@redhat.com> - 0.2.11-1
- initial package, version 0.2.11 (stable)
